@@ -1,3 +1,5 @@
+#' GWLelast.est
+#'
 #' Fitting geographically weighted logistic elastic net regression
 #'
 #' @param x Covariates.
@@ -10,34 +12,33 @@
 #' @param longlat Indicate if the coords parameter are sperically calculated.
 #' @param bw bandwidth of geographical kernel function.
 #' @param D Distance matrix.
-#' @param Parallel Calculate the model with multi core or not.
-#' @return model Fitted model at location i.
-#' @return cv.error Cross validation error.
+#'
+#' @importFrom stats dist
+#'
+#' @return model: Fitted model at location i.
+#' @return error: Cross validation error.
+#' @export
+
+GWLelast.est = function(x, y, coords, D = NULL, alpha = 1, lambda = NULL,
+                        nlambda = NULL, gweight = c("gwr.Gauss","gwr.bisquare"),
+                        longlat = TRUE, bw = bw
+) {
+
 
-GWLelast.est = function(x, y, coords, alpha = 1, lambda = NULL, 
-                           nlambda = NULL, gweight = c("gwr.Gauss","gwr.bisquare"), 
-                           longlat = TRUE, bw = bw, 
-                           D = NULL, Parallel = FALSE) {
-  
-  
   if(is.null(D) & longlat){
     D = distm(coords)
   }else if(is.null(D) & !longlat){
     D = dist(coords)
   }
-  
+
   if(is.null(bw)){
-    cat("Please set a bandwidth parameter!")
+    cat("Please select a bandwidth parameter (bw)!")
   }
-  
+
   W = gweight(D, bw)
   result = list()
-  
-  if(Parallel){
-    result = GWLelast.inner.parallel(x=x, y = y, coords = coords, W = W, alpha = alpha, lambda = lambda, nlambda = nlambda)
-  }else{
-    result = GWLelast.inner(x=x, y = y, coords = coords, W = W, lambda = lambda, alpha = alpha, nlambda = nlambda)
-  }
-  
+
+  result = GWLelast.inner(x=x, y = y, coords = coords, W = W, lambda = lambda, alpha = alpha, nlambda = nlambda)
+
   return(result)
 }
